==> jc-1.4.0.tar.gz: java/awt/Canvas__24AccessibleAWTCanvas.h <==
// public class java.awt.Canvas$AccessibleAWTCanvas

// class file dependencies
// @dep_class 9b5ceaab85260795 java_awt_Canvas__24AccessibleAWTCanvas
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_Component__24AccessibleAWTComponent

#include "java/awt/Component__24AccessibleAWTComponent.h"

#ifndef _JC_java_awt_Canvas__24AccessibleAWTCanvas_H_
#define _JC_java_awt_Canvas__24AccessibleAWTCanvas_H_

// Forward structure declarations
struct _jc_java_awt_Canvas$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;

// Typedefs
typedef struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$sub_refs	_jc_java_awt_Canvas__24AccessibleAWTCanvas$sub_refs;
typedef struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$sub_nonrefs	_jc_java_awt_Canvas__24AccessibleAWTCanvas$sub_nonrefs;
typedef struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$refs	_jc_java_awt_Canvas__24AccessibleAWTCanvas$refs;
typedef struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$nonrefs	_jc_java_awt_Canvas__24AccessibleAWTCanvas$nonrefs;
typedef struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$object	_jc_java_awt_Canvas__24AccessibleAWTCanvas$object;

typedef struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$fields_struct	_jc_java_awt_Canvas__24AccessibleAWTCanvas$fields_struct;
typedef const struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$vmethods	_jc_java_awt_Canvas__24AccessibleAWTCanvas$vmethods;
typedef const struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$vtable	_jc_java_awt_Canvas__24AccessibleAWTCanvas$vtable;
typedef const struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$vtype	_jc_java_awt_Canvas__24AccessibleAWTCanvas$vtype;

// Class fields structure
struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_Canvas__24AccessibleAWTCanvas$fields_struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$class_fields;

// Constructors
extern void _jc_java_awt_Canvas__24AccessibleAWTCanvas$method$_init$9e00c4cc6f3083bc(_jc_env *, struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$object *, struct _jc_java_awt_Canvas$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_java_awt_Canvas__24AccessibleAWTCanvas$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_Canvas__24AccessibleAWTCanvas$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$object *);
};

// Vtable
struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Canvas__24AccessibleAWTCanvas$vmethods	java_awt_Canvas__24AccessibleAWTCanvas;
};

// Vtype
struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$vtype {
	_jc_type			type;
	_jc_java_awt_Canvas__24AccessibleAWTCanvas$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$sub_refs {
	struct _jc_java_awt_Canvas$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$refs {
    _jc_java_awt_Canvas__24AccessibleAWTCanvas$sub_refs	java_awt_Canvas__24AccessibleAWTCanvas;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Canvas__24AccessibleAWTCanvas$sub_nonrefs	java_awt_Canvas__24AccessibleAWTCanvas;
};

// Object instance structure
struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$object {
	_jc_java_awt_Canvas__24AccessibleAWTCanvas$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Canvas__24AccessibleAWTCanvas$vtype	*vtype;
	_jc_java_awt_Canvas__24AccessibleAWTCanvas$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Canvas__24AccessibleAWTCanvas$vtype _jc_java_awt_Canvas__24AccessibleAWTCanvas$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Canvas__24AccessibleAWTCanvas, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Canvas__24AccessibleAWTCanvas$class_object;

#endif	/* _JC_java_awt_Canvas__24AccessibleAWTCanvas_H_ */

==> jc-1.4.5.tar.gz: java/awt/Canvas__24AccessibleAWTCanvas.h <==
// public class java.awt.Canvas$AccessibleAWTCanvas

// class file dependencies
// @dep_class 9b5ceaab85260795 java_awt_Canvas__24AccessibleAWTCanvas
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_Component__24AccessibleAWTComponent

#include "java/awt/Component__24AccessibleAWTComponent.h"

#ifndef _JC_java_awt_Canvas__24AccessibleAWTCanvas_H_
#define _JC_java_awt_Canvas__24AccessibleAWTCanvas_H_

// Forward structure declarations
struct _jc_java_awt_Canvas$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;

// Typedefs
typedef struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$sub_refs	_jc_java_awt_Canvas__24AccessibleAWTCanvas$sub_refs;
typedef struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$sub_nonrefs	_jc_java_awt_Canvas__24AccessibleAWTCanvas$sub_nonrefs;
typedef struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$refs	_jc_java_awt_Canvas__24AccessibleAWTCanvas$refs;
typedef struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$nonrefs	_jc_java_awt_Canvas__24AccessibleAWTCanvas$nonrefs;
typedef struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$object	_jc_java_awt_Canvas__24AccessibleAWTCanvas$object;

typedef struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$fields_struct	_jc_java_awt_Canvas__24AccessibleAWTCanvas$fields_struct;
typedef const struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$vmethods	_jc_java_awt_Canvas__24AccessibleAWTCanvas$vmethods;
typedef const struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$vtable	_jc_java_awt_Canvas__24AccessibleAWTCanvas$vtable;
typedef const struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$vtype	_jc_java_awt_Canvas__24AccessibleAWTCanvas$vtype;

// Class fields structure
struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_Canvas__24AccessibleAWTCanvas$fields_struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$class_fields;

// Constructors
extern void _jc_java_awt_Canvas__24AccessibleAWTCanvas$method$_init$9e00c4cc6f3083bc(_jc_env *, struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$object *, struct _jc_java_awt_Canvas$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_java_awt_Canvas__24AccessibleAWTCanvas$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_Canvas__24AccessibleAWTCanvas$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Canvas__24AccessibleAWTCanvas$vmethods	java_awt_Canvas__24AccessibleAWTCanvas;
};

// Vtype
struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$vtype {
	_jc_type			type;
	_jc_java_awt_Canvas__24AccessibleAWTCanvas$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$sub_refs {
	struct _jc_java_awt_Canvas$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$refs {
    _jc_java_awt_Canvas__24AccessibleAWTCanvas$sub_refs	java_awt_Canvas__24AccessibleAWTCanvas;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Canvas__24AccessibleAWTCanvas$sub_nonrefs	java_awt_Canvas__24AccessibleAWTCanvas;
};

// Object instance structure
struct _jc_java_awt_Canvas__24AccessibleAWTCanvas$object {
	_jc_java_awt_Canvas__24AccessibleAWTCanvas$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Canvas__24AccessibleAWTCanvas$vtype	*vtype;
	_jc_java_awt_Canvas__24AccessibleAWTCanvas$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Canvas__24AccessibleAWTCanvas$vtype _jc_java_awt_Canvas__24AccessibleAWTCanvas$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Canvas__24AccessibleAWTCanvas, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Canvas__24AccessibleAWTCanvas$class_object;

#endif	/* _JC_java_awt_Canvas__24AccessibleAWTCanvas_H_ */
